@@ -6,7 +6,7 @@ from pathlib import Path
 import typer
 import multiprocessing
 
-from pyplexity.perpl_computer import PerplexityComputer, PerplexityProcessor
+from pyplexity.perpl_model import PerplexityModel, PerplexityProcessor
 from tqdm import tqdm
 
 from pyplexity import distributed_files_server
@@ -44,7 +44,7 @@ def bulk_perplexity(input_dir: str,
                     n_workers: int = 1,
                     node: int = 1,
                     port: int = 8866):
-    perpl_computer = PerplexityComputer.from_str(model)
+    perpl_computer = PerplexityModel.from_str(model)
     content_processor = PerplexityProcessor(perpl_computer, perpl_limit)
     processor = DatasetProcessor(base_dir=input_dir, output_dir=output_dir, content_processor=content_processor)
     execute_processor(input_dir, distributed, n_workers, node, port, processor, warc_input)
@@ -53,7 +53,7 @@ def bulk_perplexity(input_dir: str,
 @app.command()
 def perplexity(text: str,
                model: str = 'bigrams-bnc'):
-    perpl_computer = PerplexityComputer.from_str(model)
+    perpl_computer = PerplexityModel.from_str(model)
     typer.echo(perpl_computer.compute_sentence(text))
 
 
